@@ -1,12 +1,22 @@
 #!/usr/bin/env python2
+from __future__ import absolute_import
+from __future__ import division
+
 import argparse
 import os
 import sys
+import io
+
+import pwnlib
+pwnlib.args.free_form = False
 
 from pwn import *
+from pwnlib.commandline import common
 
-parser = argparse.ArgumentParser(
-    description = 'Pwnlib HexDump'
+parser = common.parser_commands.add_parser(
+    'phd',
+    help = 'Pretty hex dump',
+    description = 'Pretty hex dump'
 )
 
 parser.add_argument(
@@ -14,8 +24,8 @@ parser.add_argument(
     metavar='file',
     nargs='?',
     help='File to hexdump.  Reads from stdin if missing.',
-    type=argparse.FileType('r'),
-    default=sys.stdin
+    type=argparse.FileType('rb'),
+    default=getattr(sys.stdin, 'buffer', sys.stdin)
 )
 
 parser.add_argument(
@@ -64,9 +74,7 @@ def asint(s):
     else:
         return int(s, 10)
 
-def main():
-    args = parser.parse_args()
-
+def main(args):
     infile = args.file
     width  = asint(args.width)
     skip   = asint(args.skip)
@@ -78,10 +86,13 @@ def main():
     text.when = color
 
     if skip:
-        if infile == sys.stdin:
-            infile.read(skip)
-        else:
+        try:
             infile.seek(skip, os.SEEK_CUR)
+        except IOError:
+            infile.read(skip)
+
+    if count != -1:
+        infile = io.BytesIO(infile.read(count))
 
     hl = []
     if args.highlight:
@@ -91,8 +102,9 @@ def main():
 
     try:
         for line in hexdump_iter(infile, width, highlight = hl, begin = offset + skip):
-            print line
+            print(line)
     except (KeyboardInterrupt, IOError):
         pass
 
-if __name__ == '__main__': main()
+if __name__ == '__main__':
+    pwnlib.commandline.common.main(__file__)
